dj_oydiv.migrations package
===========================

Submodules
----------

dj_oydiv.migrations.0001_initial module
---------------------------------------

.. automodule:: dj_oydiv.migrations.0001_initial
    :members:
    :undoc-members:
    :show-inheritance:

dj_oydiv.migrations.0002_auto_20151120_0227 module
--------------------------------------------------

.. automodule:: dj_oydiv.migrations.0002_auto_20151120_0227
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: dj_oydiv.migrations
    :members:
    :undoc-members:
    :show-inheritance:
